==> eiffelstudio-19.05.10.3187.tar: F_code/C22/dt1087.c <==
/*
 * Code for class DT_DATE_TIME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt1087.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_DATE_TIME}.make */
void F1966_19268 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4, EIF_INTEGER_32 arg5, EIF_INTEGER_32 arg6)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F1963_19197(Current, arg1, arg2, arg3);
	F1960_19117(Current, arg4, arg5, arg6);
	RTLE;
}

/* {DT_DATE_TIME}.make_from_storage */
void F1966_19273 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) = (EIF_INTEGER_32) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) arg2;
	RTLE;
}

/* {DT_DATE_TIME}.duration */
EIF_REFERENCE F1966_19276 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_INTEGER_32 ti4_6;
	EIF_INTEGER_32 ti4_7;
	EIF_INTEGER_32 ti4_8;
	EIF_INTEGER_32 ti4_9;
	EIF_INTEGER_32 ti4_10;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	Result = RTLNS(eif_new_type(1964, 0x01).id, 1964, _OBJSIZ_0_0_0_7_0_0_0_0_);
	ti4_1 = F1963_19209(Current);
	ti4_2 = F1963_19209(RTCW(arg1));
	ti4_3 = F1960_19122(Current);
	ti4_4 = F1960_19122(RTCW(arg1));
	ti4_5 = F1960_19123(Current);
	ti4_6 = F1960_19123(RTCW(arg1));
	ti4_7 = F1960_19124(Current);
	ti4_8 = F1960_19124(RTCW(arg1));
	ti4_9 = F1960_19125(Current);
	ti4_10 = F1960_19125(RTCW(arg1));
	F1965_19242(RTCW(Result), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (ti4_1 - ti4_2), (EIF_INTEGER_32) (ti4_3 - ti4_4), (EIF_INTEGER_32) (ti4_5 - ti4_6), (EIF_INTEGER_32) (ti4_7 - ti4_8), (EIF_INTEGER_32) (ti4_9 - ti4_10));
	RTLE;
	return Result;
}

/* {DT_DATE_TIME}.hash_code */
EIF_INTEGER_32 F1966_19277 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ti4_1);
	if ((EIF_BOOLEAN) (Result < ((EIF_INTEGER_32) 0L))) {
		Result = (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	}
	RTLE;
	return Result;
}

/* {DT_DATE_TIME}.add_duration */
void F1966_19278 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_5_);
	ti4_3 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_4_);
	F1963_19223(Current, ti4_1, ti4_2, ti4_3);
	loc1 = F1959_19093(RTCW(arg1));
	if ((EIF_BOOLEAN)(loc1 != ((EIF_INTEGER_32) 0L))) {
		F1966_19282(Current, loc1);
	}
	RTLE;
}

/* {DT_DATE_TIME}.add_milliseconds */
void F1966_19282 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_64 loc1 = (EIF_INTEGER_64) 0;
	EIF_INTEGER_64 loc2 = (EIF_INTEGER_64) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 != ((EIF_INTEGER_32) 0L))) {
		loc2 = (EIF_INTEGER_64) arg1;
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		loc1 = (EIF_INTEGER_64) ti4_1;
		loc1 = (EIF_INTEGER_64) (EIF_INTEGER_64) (loc1 + loc2);
		F1966_19285(Current, loc1);
	}
	RTLE;
}

/* {DT_DATE_TIME}.is_less */
EIF_BOOLEAN F1966_19283 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	Result = '\01';
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_1_);
	if (!(EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) < ti4_1)) {
		tb1 = '\0';
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_1_);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) == ti4_1)) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_0_);
			tb1 = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) < ti4_1);
		}
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {DT_DATE_TIME}.set_normalized_time_storage */
void F1966_19285 (EIF_REFERENCE Current, EIF_INTEGER_64 arg1)
{
	GTCX
	EIF_INTEGER_64 ti8_1;
	EIF_INTEGER_64 ti8_2;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg1 < (EIF_INTEGER_64) ((EIF_INTEGER_32) 0L))) {
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) ((EIF_INTEGER_64) ((EIF_INTEGER_64) -((EIF_INTEGER_64) ((EIF_INTEGER_64) -arg1 / ti8_1)) - (EIF_INTEGER_64) ((EIF_INTEGER_32) 1L)));
		F1963_19226(Current, ti4_1);
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti8_2 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) ((EIF_INTEGER_64) (ti8_1 - ((EIF_INTEGER_64) ((EIF_INTEGER_64) -arg1 % ti8_2))));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	} else {
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_64) (arg1 / ti8_1);
		F1963_19226(Current, ti4_1);
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_64) (arg1 % ti8_1);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTLE;
}

void EIF_Minit1087 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C22/dt1087.c <==
/*
 * Code for class DT_DATE_TIME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt1087.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_DATE_TIME}.make */
void F2036_21269 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4, EIF_INTEGER_32 arg5, EIF_INTEGER_32 arg6)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F2033_21195(Current, arg1, arg2, arg3);
	F2030_21115(Current, arg4, arg5, arg6);
	RTLE;
}

/* {DT_DATE_TIME}.make_from_storage */
void F2036_21274 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) = (EIF_INTEGER_32) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) arg2;
	RTLE;
}

/* {DT_DATE_TIME}.duration */
EIF_REFERENCE F2036_21277 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_INTEGER_32 ti4_5;
	EIF_INTEGER_32 ti4_6;
	EIF_INTEGER_32 ti4_7;
	EIF_INTEGER_32 ti4_8;
	EIF_INTEGER_32 ti4_9;
	EIF_INTEGER_32 ti4_10;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	Result = RTLNS(eif_new_type(2034, 0x01).id, 2034, _OBJSIZ_0_0_0_7_0_0_0_0_);
	ti4_1 = F2033_21207(Current);
	ti4_2 = F2033_21207(RTCW(arg1));
	ti4_3 = F2030_21120(Current);
	ti4_4 = F2030_21120(RTCW(arg1));
	ti4_5 = F2030_21121(Current);
	ti4_6 = F2030_21121(RTCW(arg1));
	ti4_7 = F2030_21122(Current);
	ti4_8 = F2030_21122(RTCW(arg1));
	ti4_9 = F2030_21123(Current);
	ti4_10 = F2030_21123(RTCW(arg1));
	F2035_21243(RTCW(Result), ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (ti4_1 - ti4_2), (EIF_INTEGER_32) (ti4_3 - ti4_4), (EIF_INTEGER_32) (ti4_5 - ti4_6), (EIF_INTEGER_32) (ti4_7 - ti4_8), (EIF_INTEGER_32) (ti4_9 - ti4_10));
	RTLE;
	return Result;
}

/* {DT_DATE_TIME}.hash_code */
EIF_INTEGER_32 F2036_21278 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ti4_1);
	if ((EIF_BOOLEAN) (Result < ((EIF_INTEGER_32) 0L))) {
		RTLE;
		return (EIF_INTEGER_32) (EIF_INTEGER_32) -(EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	}
	RTLE;
	return Result;
}

/* {DT_DATE_TIME}.add_duration */
void F2036_21279 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_6_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_5_);
	ti4_3 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_4_);
	F2033_21221(Current, ti4_1, ti4_2, ti4_3);
	loc1 = F2029_21091(RTCW(arg1));
	if ((EIF_BOOLEAN)(loc1 != ((EIF_INTEGER_32) 0L))) {
		F2036_21283(Current, loc1);
	}
	RTLE;
}

/* {DT_DATE_TIME}.add_milliseconds */
void F2036_21283 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_64 loc1 = (EIF_INTEGER_64) 0;
	EIF_INTEGER_64 loc2 = (EIF_INTEGER_64) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 != ((EIF_INTEGER_32) 0L))) {
		loc2 = (EIF_INTEGER_64) arg1;
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_);
		loc1 = (EIF_INTEGER_64) ti4_1;
		loc1 = (EIF_INTEGER_64) (EIF_INTEGER_64) (loc1 + loc2);
		F2036_21286(Current, loc1);
	}
	RTLE;
}

/* {DT_DATE_TIME}.is_less */
EIF_BOOLEAN F2036_21284 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	Result = '\01';
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_1_);
	if (!(EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) < ti4_1)) {
		tb1 = '\0';
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_1_);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_1_) == ti4_1)) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_0_0_0_);
			tb1 = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) < ti4_1);
		}
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {DT_DATE_TIME}.set_normalized_time_storage */
void F2036_21286 (EIF_REFERENCE Current, EIF_INTEGER_64 arg1)
{
	GTCX
	EIF_INTEGER_64 ti8_1;
	EIF_INTEGER_64 ti8_2;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN) (arg1 < (EIF_INTEGER_64) ((EIF_INTEGER_32) 0L))) {
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) ((EIF_INTEGER_64) ((EIF_INTEGER_64) -(EIF_INTEGER_64) ((EIF_INTEGER_64) -arg1 / ti8_1) - (EIF_INTEGER_64) ((EIF_INTEGER_32) 1L)));
		F2033_21224(Current, ti4_1);
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti8_2 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_64) (ti8_1 - (EIF_INTEGER_64) ((EIF_INTEGER_64) -arg1 % ti8_2));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	} else {
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_64) (arg1 / ti8_1);
		F2033_21224(Current, ti4_1);
		ti8_1 = (EIF_INTEGER_64) ((EIF_INTEGER_32) 86400000L);
		ti4_1 = (EIF_INTEGER_32) (EIF_INTEGER_64) (arg1 % ti8_1);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	RTLE;
}

void EIF_Minit1087 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
